==> ws-v3.70.7-src.tar.gz: ws-v3.70-7/include/win/WSDwinDragDrop.h <==
//
// Copyright (C) 1999-2004 Toshikaz Hirabayashi
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.
// Except as contained in this notice, the name of Toshikaz Hirabayashi shall 
// not be used in advertising or otherwise to promote the sale, use or other 
// dealings in this Software without prior written authorization from  
// Toshikaz Hirabayashi.


#ifndef WSDWINDRAGDROP_H
#define WSDWINDRAGDROP_H

#include <WScom.h>
#include <WSDdragDrop.h>
#include <WSClistData.h>

class WSDwinDragDrop               :public WSDdragDrop {

  private:
  protected:

  WSClistData  _drop_site_list;
  WSClistData  _drop_site_reglist;
  WSCbool      _under_dragging;
static  WSCbase*     _drag_client;
  WSCushort _mouse_back;
  static void _btn_press_drag_start(WSCbase*);
//  static void EnterCallback(Widget w,XtPointer data,XtPointer call_data);
  public:
    WSDwinDragDrop();
virtual          ~WSDwinDragDrop();

  virtual  long registerDragSite(WSCbase*,char* msg);
  virtual  long unregisterDragSite(WSCbase*);
  virtual  long registerDropSite(WSCbase*,char* msg,void(*)(WSCbase*,WSCbase*));
  virtual  long unregisterDropSite(WSCbase*);

  WSCbool  getDragState();
  void     executeDrop();
  WSMFclassDef(WSDwinDragDrop,WSDdragDrop);

};
extern WSDwinDragDrop* WSGIwinAppDragDrop();

#endif //WSDXDRAGDROP_H

==> ws-v3.93.2-src.tar.gz: ws-v3.93-2/include/win/WSDwinDragDrop.h <==
//
// Copyright (C) 1999-2006 WideStudio/MWT Project Team
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.


#ifndef WSDWINDRAGDROP_H
#define WSDWINDRAGDROP_H

#include <WScom.h>
#include <WSDdragDrop.h>
#include <WSClistData.h>

class WSDwinDragDrop               :public WSDdragDrop {

  private:
  protected:

  WSClistData  _drop_site_list;
  WSClistData  _drop_site_reglist;
  WSCbool      _under_dragging;
static  WSCbase*     _drag_client;
  WSCushort _mouse_back;
  WSDLEX32 static void _btn_press_drag_start(WSCbase*);
//  static void EnterCallback(Widget w,XtPointer data,XtPointer call_data);
  public:
    WSDLEX32 WSDwinDragDrop();
WSDLEX32 virtual          ~WSDwinDragDrop();

  WSDLEX32 virtual  long registerDragSite(WSCbase*,char* msg);
  WSDLEX32 virtual  long unregisterDragSite(WSCbase*);
  WSDLEX32 virtual  long registerDropSite(WSCbase*,char* msg,void(*)(WSCbase*,WSCbase*));
  WSDLEX32 virtual  long unregisterDropSite(WSCbase*);

  WSDLEX32 WSCbool  getDragState();
  WSDLEX32 void     executeDrop();
  WSMFclassDef(WSDwinDragDrop,WSDdragDrop);

};
extern WSDLEX32 WSDwinDragDrop* WSGIwinAppDragDrop();

#endif //WSDWINDRAGDROP_H
